@@ -4,7 +4,9 @@ from itertools import product
 from math import pi
 from typing import Any
 from typing import Dict
+from typing import Optional
 from typing import TYPE_CHECKING
+from typing import Union
 
 import requests
 from qiskit.circuit import Measure
@@ -48,7 +50,7 @@ class QRydBackend(Backend):
     <https://api.qryddemo.itp3.uni-stuttgart.de/docs>`_ endpoint for submitting
     simulation jobs to QRydDemo's cloud emulator."""
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         """Initialize the class.
 
         Args:
@@ -103,7 +105,9 @@ class QRydBackend(Backend):
             fusion_max_qubits=4,
         )
 
-    def set_option(self, key: str, value):
+    def set_option(
+        self, key: str, value: Union[Optional[int], Optional[bool], Optional[str]]
+    ) -> None:
         r"""Set an option.
 
         Args:
@@ -478,12 +482,13 @@ class QRydEmuCloudcompSquare(QRydBackend):
 
     Typical usage example:
 
-    .. code-block:: python
+    .. testcode::
 
         from qiskit_qryd_provider import QRydProvider
         from qiskit import QuantumCircuit, execute
+        import os
 
-        provider = QRydProvider("MY_TOKEN")
+        provider = QRydProvider(os.getenv("QRYD_API_TOKEN"))
         backend = provider.get_backend("qryd_emu_cloudcomp_square")
 
         qc = QuantumCircuit(2, 2)
@@ -494,7 +499,7 @@ class QRydEmuCloudcompSquare(QRydBackend):
 
     """
 
-    def __init__(self, provider: "qiskit_qryd_provider.QRydProvider"):
+    def __init__(self, provider: "qiskit_qryd_provider.QRydProvider") -> None:
         """Initialize the backend.
 
         Args:
@@ -585,12 +590,13 @@ class QRydEmuCloudcompTriangle(QRydBackend):
 
     Typical usage example:
 
-    .. code-block:: python
+    .. testcode::
 
         from qiskit_qryd_provider import QRydProvider
         from qiskit import QuantumCircuit, execute
+        import os
 
-        provider = QRydProvider("MY_TOKEN")
+        provider = QRydProvider(os.getenv("QRYD_API_TOKEN"))
         backend = provider.get_backend("qryd_emu_cloudcomp_triangle")
 
         qc = QuantumCircuit(2, 2)
@@ -601,7 +607,7 @@ class QRydEmuCloudcompTriangle(QRydBackend):
 
     """
 
-    def __init__(self, provider: "qiskit_qryd_provider.QRydProvider"):
+    def __init__(self, provider: "qiskit_qryd_provider.QRydProvider") -> None:
         """Initialize the backend.
 
         Args:
@@ -691,12 +697,13 @@ class QRydEmuLocalcompSquare(QRydBackend):
 
     Typical usage example:
 
-    .. code-block:: python
+    .. testcode::
 
         from qiskit_qryd_provider import QRydProvider
         from qiskit import QuantumCircuit, execute
+        import os
 
-        provider = QRydProvider("MY_TOKEN")
+        provider = QRydProvider(os.getenv("QRYD_API_TOKEN"))
         backend = provider.get_backend("qryd_emu_localcomp_square")
 
         qc = QuantumCircuit(2, 2)
@@ -707,7 +714,7 @@ class QRydEmuLocalcompSquare(QRydBackend):
 
     """
 
-    def __init__(self, provider: "qiskit_qryd_provider.QRydProvider"):
+    def __init__(self, provider: "qiskit_qryd_provider.QRydProvider") -> None:
         """Initialize the backend.
 
         Args:
@@ -773,12 +780,13 @@ class QRydEmuLocalcompTriangle(QRydBackend):
 
     Typical usage example:
 
-    .. code-block:: python
+    .. testcode::
 
         from qiskit_qryd_provider import QRydProvider
         from qiskit import QuantumCircuit, execute
+        import os
 
-        provider = QRydProvider("MY_TOKEN")
+        provider = QRydProvider(os.getenv("QRYD_API_TOKEN"))
         backend = provider.get_backend("qryd_emu_localcomp_triangle")
 
         qc = QuantumCircuit(2, 2)
@@ -789,7 +797,7 @@ class QRydEmuLocalcompTriangle(QRydBackend):
 
     """
 
-    def __init__(self, provider: "qiskit_qryd_provider.QRydProvider"):
+    def __init__(self, provider: "qiskit_qryd_provider.QRydProvider") -> None:
         """Initialize the backend.
 
         Args:
