@@ -19,7 +19,7 @@ class PCZGate(Gate):
     The PCZ gate is the controlled-Z gate up to single-qubit phase gates.
     It can be realized by the Rydberg platform in multiple ways [`1
     <https://doi.org/10.1103/PhysRevLett.123.170503>`__,
-    `2 <https://doi.org/10.48550/arXiv.2202.13849>`__,
+    `2 <https://doi.org/10.1103/PhysRevResearch.4.033019>`__,
     `3 <https://doi.org/10.22331/q-2022-05-13-712>`__].
 
     Unitary matrix representation:
@@ -36,10 +36,10 @@ class PCZGate(Gate):
 
     The phase shift :math:`\theta` has the default value 2.13, as calculated
     for experimentally realistic parameters [`2
-    <https://doi.org/10.48550/arXiv.2202.13849>`__].
+    <https://doi.org/10.1103/PhysRevResearch.4.033019>`__].
     It can be modified before using the :class:`~qiskit_qryd_provider.QRydProvider` via:
 
-    .. code-block:: python
+    .. testcode::
 
         from qiskit_qryd_provider import PCZGate
 
@@ -47,7 +47,7 @@ class PCZGate(Gate):
 
     """
 
-    def __init__(self, label: str = None):
+    def __init__(self, label: str = None) -> None:
         """Create a new PCZ gate.
 
         Args:
@@ -56,7 +56,7 @@ class PCZGate(Gate):
         """
         super().__init__("pcz", 2, [], label=label)
 
-    def _define(self):
+    def _define(self) -> None:
         qc = QuantumCircuit(2)
         qc.u(0, 0, self._theta, 0)
         qc.u(0, 0, self._theta, 1)
@@ -92,7 +92,7 @@ class PCZGate(Gate):
         return self._kraus
 
     @classmethod
-    def set_theta(cls, theta: float):
+    def set_theta(cls, theta: float) -> None:
         """Set the phase shift of the gate.
 
         Note that after setting the phase shift to a new value, an updated
@@ -144,7 +144,7 @@ class PCZGate(Gate):
         return cls._theta
 
     @classmethod
-    def set_kraus(cls, kraus: List[List[List[complex]]] = None):
+    def set_kraus(cls, kraus: List[List[List[complex]]] = None) -> None:
         """Set the Kraus representation of the gate.
 
         Args:
