@@ -26,12 +26,13 @@ class QRydJob(Job):
 
     Typical usage example:
 
-    .. code-block:: python
+    .. testcode::
 
         from qiskit_qryd_provider import QRydProvider
         from qiskit import QuantumCircuit, execute
+        import os
 
-        provider = QRydProvider("MY_TOKEN")
+        provider = QRydProvider(os.getenv("QRYD_API_TOKEN"))
         backend = provider.get_backend("qryd_emu_localcomp_square")
 
         qc = QuantumCircuit(2, 2)
@@ -42,6 +43,11 @@ class QRydJob(Job):
 
         print(job.result().get_counts())
 
+    .. testoutput::
+        :hide:
+
+        ...
+
     """
 
     _async = True
@@ -53,7 +59,7 @@ class QRydJob(Job):
         session: requests.Session,
         options: "qiskit.providers.Options",
         circuit: "qiskit.QuantumCircuit",
-    ):
+    ) -> None:
         """Initializes the asynchronous job.
 
         Args:
@@ -73,7 +79,7 @@ class QRydJob(Job):
         self._memory = options.memory
         self._shots = options.shots
 
-    def submit(self):
+    def submit(self) -> None:
         """Not implemented.
 
         Please use :func:`QRydSimulator.run()
